OC.L10N.register(
    "core",
    {
    "Please select a file." : "יש לבחור קובץ.",
    "File is too big" : "הקובץ גדול מדי",
    "The selected file is not an image." : "הקובץ שנבחר אינו קובץ תמונה",
    "The selected file cannot be read." : "לא ניתן לקרוא את הקובץ שנבחר",
    "The file was uploaded" : "הקובץ הועלה",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "הקובץ שהועלה חורג מההנחיה upload_max_filesize ב־php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה חורג מההנחיה MAX_FILE_SIZE שצוינה בטופס ה־HTML",
    "The file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
    "No file was uploaded" : "לא הועלה קובץ",
    "Missing a temporary folder" : "חסרה תיקייה זמנית",
    "Could not write file to disk" : "לא ניתן לכתוב לכונן",
    "A PHP extension stopped the file upload" : "הרחבת PHP עצרה את העלאת הקובץ",
    "Invalid file provided" : "סופק קובץ לא חוקי",
    "No image or file provided" : "לא סופקו תמונה או קובץ",
    "Unknown filetype" : "סוג קובץ לא מוכר",
    "An error occurred. Please contact your admin." : "אירעה שגיאה. יש ליצור קשר עם המנהל שלך.",
    "Invalid image" : "תמונה לא חוקית",
    "State token does not match" : "קוד אימות מצב אינו תואם",
    "Invalid app password" : "ססמת היישומון שגויה",
    "Could not complete login" : "לא ניתן להשלים את הכניסה",
    "Your login token is invalid or has expired" : "אסימון הכניסה שלך שגוי או שהוא פג",
    "Login" : "כניסה",
    "Password reset is disabled" : "אין אפשרות לאפס ססמה",
    "%s password reset" : "%s הסיסמא אופסה",
    "Password reset" : "איפוס ססמה",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "לחיצה על הכפתור הבא תוביל לאיפוס הססמה, אם לא ביקשת לאפס ססמה יש להתעלם מהודעה זו",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "יש ללחוץ על הקישור הבא כדי לאפס ססמה, אם לא ביקשת לאפס ססמה יש להתעלם מהודעה זו",
    "Reset your password" : "איפוס הססמה שלך",
    "Internal error" : "שגיאה פנימית",
    "Not found" : "לא נמצא",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "שלב בתיקון:",
    "Repair info:" : "פרטי תיקון:",
    "Repair warning:" : "אזהרת תיקון:",
    "Repair error:" : "שגיאת תיקון:",
    "Nextcloud Server" : "שרת Nextcloud",
    "Some of your link shares have been removed" : "חלק מקישורי השיתופים שלך הוסרו",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "עקב תקלת אבטחה נאלצנו להסיר חלק מקישורי השיתופים שלך. נא להיכנס לקישור לקבלת פרטים נוספים.",
    "Learn more ↗" : "מידע נוסף ↖ ",
    "Preparing update" : "מכין עדכון",
    "Turned on maintenance mode" : "הפעלת מצב אחזקה",
    "Turned off maintenance mode" : "כיבוי מצב אחזקה",
    "Maintenance mode is kept active" : "מצב אחזקה נשמר פעיל",
    "Updating database schema" : "עדכון סכימת מסד נתונים",
    "Updated database" : "עדכון מסד נתונים",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "בודק אם סכימת מסד הנתונים עבור %s ניתנת לעדכון (פעולה זו יכולה להמשך זמן רב תלוי בגודל מסד הנתונים)",
    "Updated \"%1$s\" to %2$s" : "„%1$s” עודכן לכדי %2$s",
    "Set log level to debug" : "קביעת רמת דיווח לתהליך ניפוי בשגיאות",
    "Reset log level" : "קביעה מחדש לרמת דיווח",
    "Starting code integrity check" : "התחלת בדיקת תקינות קוד",
    "Finished code integrity check" : "סיום בדיקת תקינות קוד",
    "%s (incompatible)" : "%s (לא תואם)",
    "The following apps have been disabled: %s" : "היישומים הבאים הושבתו: %s",
    "Already up to date" : "כבר עדכני",
    "Unknown" : "לא ידוע",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "העדכון מתבצע, יציאה מהעמוד הזה עשויה להפריע לתהליך בסביבות מסוימות.",
    "Update to {version}" : "עדכון ל־{version}",
    "An error occurred." : "אירעה שגיאה.",
    "Please reload the page." : "יש להעלות מחדש דף זה.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "העדכון לא בוצע בהצלחה. למידע נוסף <a href=\"{url}\">ניתן לבדוק בהודעת הפורום שלנו</a> המכסה נושא זו.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "העדכון לא הצליח. נא לדווח על התקלה הזאת ל<a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">קהילת Nextcloud</a>.",
    "Done" : "הסתיים",
    "Apps" : "יישומים",
    "More apps" : "יישומים נוספים",
    "No" : "לא",
    "Yes" : "כן",
    "Grant access" : "הענקת גישה",
    "Failed to add the public link to your Nextcloud" : "אירע כשל בהוספת קישור ציבורי ל־Nextcloud שלך",
    "Create share" : "צור שיתוף",
    "Start typing to search" : "להתחלת החיפוש יש להקליד",
    "Today" : "היום",
    "Last year" : "שנה שעברה",
    "Places" : "מקומות",
    "Date" : "תאריך",
    "Load more results" : "לטעון עוד תוצאות",
    "Log in" : "כניסה",
    "Account name or email" : "שם משתמש או דואר אלקטרוני",
    "Server side authentication failed!" : "אימות לצד שרת נכשל!",
    "Please contact your administrator." : "יש ליצור קשר עם המנהל.",
    "An internal error occurred." : "אירעה שגיאה פנימית.",
    "Please try again or contact your administrator." : "יש לנסות שוב ליצור קשר עם המנהל שלך.",
    "Password" : "ססמה",
    "Log in with a device" : "כניסה עם מכשיר",
    "Your account is not setup for passwordless login." : "החשבון שלך לא מוגדר לכניסה בלי ססמה.",
    "Passwordless authentication is only available over a secure connection." : "אימות ללא ססמה זמין רק דרך חיבור מאובטח.",
    "Passwordless authentication is not supported in your browser." : "אימות ללא ססמה אינו נתמך על ידי הדפדפן שלך.",
    "Reset password" : "איפוס ססמה",
    "Back to login" : "חזרה לכניסה",
    "Couldn't send reset email. Please contact your administrator." : "לא ניתן היה לשלוח דואר אלקטרוני לאיפוס. יש לפנות למנהל שלך.",
    "New password" : "ססמה חדשה",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "הקבצים שלך מוצפנים. לא תהיה שום דרך להחזיר את הנתונים לאחר איפוס הסיסמה. אם אינך בטוח מה לעשות, פנה למנהל המערכת לפני שתמשיך. האם אתה באמת רוצה להמשיך?",
    "I know what I'm doing" : "אני יודע/ת מה אני עושה",
    "Resetting password" : "איפוס ססמה",
    "Schedule work & meetings, synced with all your devices." : "תזמון עבודה ופגישות בסנכרון עם כל המכשירים שלך.",
    "Keep your colleagues and friends in one place without leaking their private info." : "עמיתים לעבודה וחברים מרוכזים במקום אחד מבלי זליגה של הפרטים האישיים שלהם.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "יישומון דוא״ל פשוט שמשתלב בצורה נחמדה עם הקבצים, אנשי הקשר והיומן.",
    "Recommended apps" : "יישומונים מומלצים",
    "App download or installation failed" : "הורדת או התקנת היישומון נכשלה",
    "Skip" : "דלג",
    "Install recommended apps" : "התקנת יישומונים מומלצים",
    "Online" : "מקוון",
    "Away" : "לא פה",
    "Busy" : "עסוק",
    "Mute all notifications" : "השתקת כל ההתראות",
    "Invisible" : "נסתרת",
    "Appear offline" : "להופיע במצב בלתי מקוון",
    "Settings menu" : "תפריט הגדרות",
    "Reset search" : "איפוס החיפוש",
    "Could not load your contacts" : "לא ניתן לטעון את אנשי הקשר שלך",
    "No contacts found" : "לא נמצאו אנשי קשר",
    "Install the Contacts app" : "התקנת יישומון אנשי הקשר",
    "Search" : "חיפוש",
    "No results for {query}" : "אין תוצאות עבור {query}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["נא להקליד לפחות תו אחד כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש"],
    "An error occurred while searching for {type}" : "אירעה שגיאה בחיפוש אחר {type}",
    "Search for {name} only" : "חפש ל-{name} בלבד",
    "Forgot password?" : "שכחת ססמה?",
    "Back" : "חזרה",
    "Connect to your account" : "התחברות לחשבון שלך",
    "Security warning" : "אזהרת אבטחה",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "אם אינך מנסה להגדיר מכשיר חדש או אפליקציה חדשה, מישהו מנסה לרמות אותך להעניק לו גישה לנתונים שלך. במקרה הזה, אל תמשיך, ובמקום זאת פנה למנהל המערכת שלך.",
    "Account connected" : "חשבון מחובר",
    "Your client should now be connected!" : "הלקוח שלך אמור להיות מחובר עכשיו!",
    "You can close this window." : "ניתן לסגור את החלון הזה.",
    "Account access" : "גישה לחשבון",
    "More actions" : "פעולות נוספות",
    "This share is password-protected" : "שיתוף זה מוגן בססמה",
    "Submit" : "שליחה",
    "Email address" : "כתובת דוא״ל",
    "Request password" : "בקשת ססמה",
    "Forgot password" : "שכחתי ססמה",
    "Storage & database" : "אחסון ומסד נתונים",
    "Data folder" : "תיקיית נתונים",
    "Install and activate additional PHP modules to choose other database types." : "לבחירת סוגים אחרים של מסדי נתונים יש להתקין ולהפעיל מודולי PHP נוספים.",
    "For more details check out the documentation." : "למידע נוסף יש לבדוק במסמכי התיעוד.",
    "Performance warning" : "אזהרת ביצועים",
    "You chose SQLite as database." : "בחרת ב־SQLite כמסד נתונים.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "יש להשתמש ב־SQLite לסביבות מזעריות או למטרות פיתוח. בסביבת פעילות שגרתית אנו ממליצים על מנגנון מסד נתונים אחר.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "אם יש לך לקוח שמשמש אותך לסנכרון קבצים, השימוש ב־SQLite לא מומלץ עבורך.",
    "Database user" : "שם משתמש במסד הנתונים",
    "Database password" : "ססמת מסד הנתונים",
    "Database name" : "שם מסד הנתונים",
    "Database tablespace" : "מרחב הכתובות של מסד הנתונים",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "נא לציין את מספר הפתחה יחד עם שם המארח (למשל: localhost:5432).",
    "Database host" : "שרת מסד נתונים",
    "Install" : "התקנה",
    "Need help?" : "עזרה נזקקת?",
    "See the documentation" : "יש לצפות במסמכי התיעוד",
    "Choose" : "בחירה",
    "Copy" : "העתקה",
    "Move" : "העברה",
    "OK" : "אישור",
    "read-only" : "לקריאה בלבד",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} הנגשות קובץ","{count} התנגשויות קבצים","{count} התנגשויות קבצים","{count} התנגשויות קבצים"],
    "One file conflict" : "התנגשות קובץ אחת",
    "New Files" : "קבצים חדשים",
    "Already existing files" : "קבצים קיימים כבר",
    "Which files do you want to keep?" : "אילו קבצים ברצונך לשמור?",
    "If you select both versions, the copied file will have a number added to its name." : "אם תבחר האפשרות לשמור את שתי הגרסאות, לשם קובץ המועתק יתווסף מספר.",
    "Cancel" : "ביטול",
    "Continue" : "המשך",
    "(all selected)" : "(הכול נבחר)",
    "({count} selected)" : "({count} נבחרו)",
    "Error loading file exists template" : "שגיאה בטעינת קובץ תבנית קיימים",
    "Saving …" : "מתבצע שמירה…",
    "Groups" : "קבוצות",
    "Group list is empty" : "רשימת הקבוצות ריקה",
    "Unable to retrieve the group list" : "לא ניתן לקבל את רשימת הקבוצות",
    "seconds ago" : "לפני מספר שניות",
    "Connection to server lost" : "החיבור לשרת אבד",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["תקלה בטעינת העמוד, יתבצע רענון בעוד שנייה","תקלה בטעינת העמוד, יתבצע רענון בעוד %n שניות","תקלה בטעינת העמוד, יתבצע רענון בעוד %n שניות","תקלה בטעינת העמוד, יתבצע רענון בעוד %n שניות"],
    "Add to a project" : "הוספה למיזם",
    "Show details" : "הצגת פרטים",
    "Hide details" : "הסתרת פרטים",
    "Rename project" : "שינוי שם מיזם",
    "Failed to rename the project" : "שינוי שם המיזם נכשל",
    "Failed to create a project" : "יצירת המיזם נכשלה",
    "Failed to add the item to the project" : "הוספת פריט למיזם נכשלה",
    "Connect items to a project to make them easier to find" : "יש לחבר פריטים למיזם כדי להקל על איתורם",
    "Type to search for existing projects" : "לחיפוש במיזמים הקיימים יש להקליד",
    "New in" : "חדש ב־",
    "View changelog" : "הצגת יומן שינויים",
    "Personal" : "אישי",
    "Accounts" : "Accounts",
    "Admin" : "מנהל",
    "Help" : "עזרה",
    "Access forbidden" : "הגישה נחסמה",
    "Back to %s" : "חזרה אל %s",
    "Page not found" : "העמוד לא נמצא",
    "Too many requests" : "יותר מדי בקשות",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "היו יותר מדי בקשות מהרשת שלך. נסה שוב מאוחר יותר, או צור קשר עם מנהל המערכת שלך אם זו שגיאה.",
    "Error" : "שגיאה",
    "Internal Server Error" : "שגיאה פנימית בשרת",
    "The server was unable to complete your request." : "השרת לא הצליח להשלים את הבקשה שלך.",
    "If this happens again, please send the technical details below to the server administrator." : "אם דבר כזה קורה שוב, נא לשלוח את הפרטים הטכניים שלהלן למנהל השרת.",
    "More details can be found in the server log." : "פרטים נוספים ניתן למצוא בלוג של הרשת.",
    "Technical details" : "פרטים טכנים",
    "Remote Address: %s" : "כתובת מרוחקת: %s",
    "Request ID: %s" : "מספר זיהוי מבוקש: %s",
    "Type: %s" : "סוג: %s",
    "Code: %s" : "קוד: %s",
    "Message: %s" : "הודעה: %s",
    "File: %s" : "קובץ: %s",
    "Line: %s" : "שורה: %s",
    "Trace" : "עקבות",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "נראה שאתה מנסה להתקין מחדש את ה-Nextcloud שלך.אבל הקובץ CAN_INSTALL חסר בספריית ה-config שלך. אנא צור את הקובץ CAN_INSTALL בתיקיית ה-config שלך כדי להמשיך.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "לא ניתן להסיר את CAN_INSTALL מתיקיית ההגדרות. נא להסיר את הקובץ הזה ידנית.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "יישום זה דורש JavaScript לפעולה נכונה. יש {linkstart}לאפשר JavaScript{linkend} ולטעון את העמוד מחדש.",
    "Skip to main content" : "דילוג לתוכן הראשי",
    "Skip to navigation of app" : "דילוג לניווט של היישומון",
    "Go to %s" : "מעבר אל %s",
    "Get your own free account" : "קבלת חשבון משלך בחינם",
    "Previous" : "הקודם",
    "Two-factor authentication" : "אימות דו־שלבי",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "על החשבון שלך מופעלת אבטחה מוגברת. נא לבחור גורם אימות נוסף:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "לא ניתן לטעון לפחות את אחד משיטות האימות הדו־שלבי שהפעלת. נא ליצור קשר עם מנהל המערכת.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "אימות דו־שלבי נאכף אך הוא אינו מוגדר על החשבון שלך. נא ליצור קשר עם המנהל שלך לקבלת עזרה.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "אימות דו-גורמי נאכף, אך לא הוגדר בחשבון שלך. אנא תמשיך להגדיר אימות דו-גורמי.",
    "Set up two-factor authentication" : "הגדרת אימות דו־שלבי",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "אימות דו־שלבי נאכף אך הוא אינו מוגדר על החשבון שלך. נא להשתמש באחד מהקודים לצורכי גיבוי כדי להיכנס או ליצור קשר עם המנהל שלך לקבלת עזרה.",
    "Use backup code" : "שימוש בקוד גיבוי",
    "Cancel login" : "ביטול התחברות",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "על החשבון שלך נאכפת אבטחה מורחבת. נא לבחור איזה ספק להגדיר:",
    "Error while validating your second factor" : "שגיאה בעת אימות הגורם השני",
    "Access through untrusted domain" : "גישה דרך שם מתחם בלתי מהימן",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "נא ליצור קשר עם מנהל השרת שלך. אם הרשאות ניהול השרת הן בידיך, יש לערוך את ההגדרה „trusted_domains” בתוך config/config.php כמו הדוגמה שבתוך ",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "ניתן למצוא מידע נוסף על אופן ההגדרה של התכונה הזאת ב%1$sתיעוד%2$s.",
    "App update required" : "נדרש עדכון יישום",
    "%1$s will be updated to version %2$s" : "%1$s יעודכן לגרסה %2$s",
    "The following apps will be updated:" : "היישומונים הבאים יעודכנו:",
    "These incompatible apps will be disabled:" : "יישומים לא תואמים ינוטרלו:",
    "The theme %s has been disabled." : "ערכת הנושא %s הושבתה.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "יש לוודא שמסד הנתונים, תיקיית config ותיקיית data גובו לפני המשך התהליך.",
    "Start update" : "התחלת עדכון",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "למניעת פסקי זמן בהתקנות גדולות, ניתן במקום להריץ את הפקודה הבאה בתיקיית ההתקנה שלך:",
    "Detailed logs" : "יומן מפורט",
    "Update needed" : "עדכון נדרש",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "לעזרה יש לעיין ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">תיעוד</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "ידוע לי שאם אמשיך דרך מנשק הדפדפן אהיה חשוף לסכנה, שהבקשה עשויה להיקלע לחוסר מענה וכתוצאה מכך אבדן נתונים, אך יש לי גיבוי וידוע לי איך לשחזר את העותק שלי במקרה של כשל.",
    "Upgrade via web on my own risk" : "השדרוג דרך האינטרנט הוא על אחריותי",
    "Maintenance mode" : "מצב תחזוקה",
    "This %s instance is currently in maintenance mode, which may take a while." : "עותק %s זה כרגע במצב תחזוקה, שיארך זמן מה.",
    "This page will refresh itself when the instance is available again." : "עמוד זה ירענן את עצמו כאשר העותק ישוב להיות זמין.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "יש ליצור קשר עם מנהל המערכת אם הודעה שו נמשכת או מופיעה באופן בלתי צפוי. ",
    "Error occurred while checking server setup" : "שגיאה אירעה בזמן בדיקת התקנת השרת",
    "unknown text" : "מלל לא מוכר",
    "Hello world!" : "שלום עולם!",
    "sunny" : "שמשי",
    "Hello {name}, the weather is {weather}" : "שלום {name}, מזג האוויר הנו {weather}",
    "Hello {name}" : "שלום {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>אלו תוצאות החיפוש שלך<script>alert(1)</script></strong>",
    "new" : "חדש",
    "_download %n file_::_download %n files_" : ["התקבל קובץ %n","התקבלו %n קבצים","התקבלו %n קבצים"],
    "Searching …" : "מתבצע חיפוש…",
    "Logging in …" : "מתבצעת כניסה…",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "זיהינו מספר ניסיונות כניסה שגויים מכתובת ה־IP שלך. לכן, ניסיון הכניסה הבא יתאפשר עבורך רק בעוד 30 שניות.",
    "Loading apps …" : "היישומונים נטענים…",
    "Installing apps …" : "היישומונים מותקנים…",
    "Loading your contacts …" : "אנשי הקשר שלך נטענים…",
    "Looking for {term} …" : "מתבצע חיפוש אחר {term}…",
    "Search contacts …" : "חיפוש אנשי קשר…",
    "Loading more results …" : "נטענות תוצאות נוספות…",
    "Search {types} …" : "חפש {types} ...",
    "Saving …" : "מתבצעת שמירה…",
    "Very weak password" : "ססמה מאוד חלשה",
    "Weak password" : "ססמה חלשה",
    "So-so password" : "ססמה בינונית",
    "Good password" : "ססמה טובה",
    "Strong password" : "ססמה חזקה",
    "No action available" : "אין פעולה זמינה",
    "Error fetching contact actions" : "שגיאה בקבלת פעולות אנשי הקשר",
    "Non-existing tag #{tag}" : "תגית לא קיימת #{tag}",
    "Restricted" : "מוגבלת",
    "Delete" : "מחיקה",
    "Rename" : "שינוי שם",
    "Collaborative tags" : "תגיות שיתופיות",
    "No tags found" : "לא נמצאו תגים",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "תיקיות וקובצי הנתונים שלך כנראה נגישים מהאינטרנט מכיוון שקובץ ה־‎.htaccess לא עובד.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "למידע בנוגע להגדרת השרת שלך כראוי, נא לעיין ב<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">תיעוד</a>.",
    "Show password" : "הצגת ססמה",
    "Configure the database" : "הגדרת מסד הנתונים",
    "Only %s is available." : "רק %s זמין.",
    "Please log in before granting %1$s access to your %2$s account." : "נא להיכנס בטרם הענקת גישה לחשבון שלך ב־%2$s לטובת %1$s.",
    "You are about to grant %1$s access to your %2$s account." : "פעולה זו תעניק ל־%1$s גישה לחשבון ה־%2$s שלך."
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
